==> girth-0.7.3.tar.gz: girth-0.7.3/setup.py <==
from setuptools import setup, convert_path # pylint: disable=cyclic-import

from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

if __name__ == '__main__':
    setup(
        name="girth", 
        packages=['girth', 'girth.three_pl', 'girth.classical',
                  'girth.multidimensional',
                  'girth.factoranalysis', 'girth.common'],
        package_dir={'girth': convert_path('./src'),
                     'girth.common': convert_path('./common'),
                     'girth.factoranalysis': convert_path('./factoranalysis')},
        version="0.7.3",
        license="MIT",
        description="A python package for Item Response Theory.",
        long_description=long_description.replace('<ins>','').replace('</ins>',''),
        long_description_content_type='text/markdown',
        author='Ryan C. Sanchez',
        author_email='ryan.sanchez@gofactr.com',
        url = 'https://eribean.github.io/girth/',
        keywords = ['IRT', 'Psychometrics', 'Item Response Theory'],
        install_requires = ['numpy', 'scipy', 'numba'],
        classifiers = [
            'Development Status :: 3 - Alpha',
            'Intended Audience :: Science/Research',
            'Topic :: Scientific/Engineering', 
            'License :: OSI Approved :: MIT License',          
            'Programming Language :: Python :: 3.8',
            'Programming Language :: Python :: 3.9'
        ]
    )

==> girth-0.7.5.tar.gz: girth-0.7.5/setup.py <==
from setuptools import setup, convert_path # pylint: disable=cyclic-import

from os import path

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

if __name__ == '__main__':
    setup(
        name="girth", 
        packages=['girth', 'girth.three_pl', 'girth.classical',
                  'girth.multidimensional',
                  'girth.factoranalysis', 'girth.common'],
        package_dir={'girth': convert_path('./src'),
                     'girth.common': convert_path('./common'),
                     'girth.factoranalysis': convert_path('./factoranalysis')},
        version="0.7.5",
        license="MIT",
        description="A python package for Item Response Theory.",
        long_description=long_description.replace('<ins>','').replace('</ins>',''),
        long_description_content_type='text/markdown',
        author='Ryan C. Sanchez',
        author_email='ryan.sanchez@gofactr.com',
        url = 'https://eribean.github.io/girth/',
        keywords = ['IRT', 'Psychometrics', 'Item Response Theory'],
        install_requires = ['numpy', 'scipy'],
        classifiers = [
            'Development Status :: 3 - Alpha',
            'Intended Audience :: Science/Research',
            'Topic :: Scientific/Engineering', 
            'License :: OSI Approved :: MIT License',          
            'Programming Language :: Python :: 3.8',
            'Programming Language :: Python :: 3.9'
        ]
    )
